# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`root`](#root): Manage root user

#### Private Classes

* `root::kerberos`: Private class
* `root::params`: Private class
* `root::rsakey::export`: Private class

### Defined types

#### Public Defined types

* [`root::ssh_authorized_key`](#rootssh_authorized_key): Define root user's ssh_authorized_key resources

#### Private Defined types

* `root::rsakey::collect`: Private class

## Classes

### <a name="root"></a>`root`

Manage root user

#### Examples

##### 

```puppet
include ::root
```

#### Parameters

The following parameters are available in the `root` class:

* [`mailaliases`](#mailaliases)
* [`mailaliases_hiera_merge`](#mailaliases_hiera_merge)
* [`ssh_authorized_keys`](#ssh_authorized_keys)
* [`ssh_authorized_keys_hiera_merge`](#ssh_authorized_keys_hiera_merge)
* [`password`](#password)
* [`purge_ssh_keys`](#purge_ssh_keys)
* [`export_key`](#export_key)
* [`export_key_options`](#export_key_options)
* [`export_key_tag`](#export_key_tag)
* [`collect_exported_keys`](#collect_exported_keys)
* [`collect_exported_keys_tags`](#collect_exported_keys_tags)
* [`ssh_private_key_source`](#ssh_private_key_source)
* [`ssh_public_key_source`](#ssh_public_key_source)
* [`logout_timeout`](#logout_timeout)
* [`manage_kerberos`](#manage_kerberos)
* [`kerberos_login_principals_hiera_merge`](#kerberos_login_principals_hiera_merge)
* [`kerberos_login_principals`](#kerberos_login_principals)
* [`kerberos_users_commands_hiera_merge`](#kerberos_users_commands_hiera_merge)
* [`kerberos_users_commands`](#kerberos_users_commands)

##### <a name="mailaliases"></a>`mailaliases`

Data type: `Array`

An array that defines mailaliases for the root user (defaults to an empty array).
When an empty array is given Mailaliases[root] is set to `ensure => absent`.

Default value: `[]`

##### <a name="mailaliases_hiera_merge"></a>`mailaliases_hiera_merge`

Data type: `Boolean`

Boolean that determines if the Hiera lookup merging is used for `root::mailaliases` values.

Default value: ``true``

##### <a name="ssh_authorized_keys"></a>`ssh_authorized_keys`

Data type: `Variant[Array, Hash]`

Defines ssh_autorized_keys to be passed to the `root::ssh_authorized_key` defined type.
See `root::ssh_authorized_key` for examples of valid formats

Default value: `{}`

##### <a name="ssh_authorized_keys_hiera_merge"></a>`ssh_authorized_keys_hiera_merge`

Data type: `Boolean`

Boolean that determines if the Hiera lookup merging `root::ssh_authorized_keys` values.

Default value: ``true``

##### <a name="password"></a>`password`

Data type: `Optional[String]`

The password hash used for the root account.

Default value: ``undef``

##### <a name="purge_ssh_keys"></a>`purge_ssh_keys`

Data type: `Boolean`

Sets if unmanaged SSH keys will be purged for the root account.

Default value: ``true``

##### <a name="export_key"></a>`export_key`

Data type: `Boolean`

Sets if the root SSH RSA key should be created and exported.

Default value: ``false``

##### <a name="export_key_options"></a>`export_key_options`

Data type: `Optional[Array]`

Options to set for the exported SSH RSA key

Default value: ``undef``

##### <a name="export_key_tag"></a>`export_key_tag`

Data type: `String`

The tag to use when exporting the root SSH RSA key.

Default value: `$::domain`

##### <a name="collect_exported_keys"></a>`collect_exported_keys`

Data type: `Boolean`

Sets if the export root SSH RSA keys should be collected.

Default value: ``false``

##### <a name="collect_exported_keys_tags"></a>`collect_exported_keys_tags`

Data type: `Array`

Array of tags for root SSH RSA keys to collect.

Default value: `[$::domain]`

##### <a name="ssh_private_key_source"></a>`ssh_private_key_source`

Data type: `Optional[String]`

The source for root's SSH RSA private key

Default value: ``undef``

##### <a name="ssh_public_key_source"></a>`ssh_public_key_source`

Data type: `Optional[String]`

The source for root's SSH RSA public key

Default value: ``undef``

##### <a name="logout_timeout"></a>`logout_timeout`

Data type: `Optional[Integer[0, default]]`

Time (in seconds) before idle interactive terminals will logout

Default value: ``undef``

##### <a name="manage_kerberos"></a>`manage_kerberos`

Data type: `Boolean`

Boolean that sets if Kerberos files should be managed

Default value: ``true``

##### <a name="kerberos_login_principals_hiera_merge"></a>`kerberos_login_principals_hiera_merge`

Data type: `Boolean`

Boolean that determines if the Hiera lookup merging `root::kerberos_login_principals` values.

Default value: ``true``

##### <a name="kerberos_login_principals"></a>`kerberos_login_principals`

Data type: `Array`

The Kerberos principals to write to /root/.k5login

Default value: `[]`

##### <a name="kerberos_users_commands_hiera_merge"></a>`kerberos_users_commands_hiera_merge`

Data type: `Boolean`

Boolean that determines if the Hiera lookup merging `root::kerberos_users_commands` values.

Default value: ``true``

##### <a name="kerberos_users_commands"></a>`kerberos_users_commands`

Data type: `Hash[String[1], Variant[String, Array]]`

The Kerberos user principals and commands to write to /root/.k5users

Default value: `{}`

## Defined types

### <a name="rootssh_authorized_key"></a>`root::ssh_authorized_key`

Define root user's ssh_authorized_key resources

#### Examples

##### Define ssh_authorized_key using Hash

```puppet
root::ssh_authorized_key { 'user@fqdn':
  type => 'ssh-rsa',
  key  => 'somelonghash==',
}
```

##### Define ssh_authorized_key using name string

```puppet
root::ssh_authorized_key { 'ssh-rsa somelonghash== user@fqdn': }
```

#### Parameters

The following parameters are available in the `root::ssh_authorized_key` defined type:

* [`ensure`](#ensure)
* [`key`](#key)
* [`options`](#options)
* [`type`](#type)

##### <a name="ensure"></a>`ensure`

Data type: `Any`

ssh_authorized_key ensure property

Default value: `'present'`

##### <a name="key"></a>`key`

Data type: `Any`

The SSH key hash

Default value: `'UNSET'`

##### <a name="options"></a>`options`

Data type: `Any`

The SSH key options

Default value: `'UNSET'`

##### <a name="type"></a>`type`

Data type: `Any`

The type of SSH key.

Default value: `'UNSET'`

